/*
 * blink.c: makes a LED connected to BCM_GPIO 17 (or wiring Pi GPIO 0) blink.
 * It captures SIGINT and clears the LED before exiting
 * copyright U. Raich 2017
 * This program is part of the workshop on embedded systems held at 
 * the University of Cape Coast in the winter semester 2017
 * It has been released under the GNU General Public License
 * see gnu.org/licenses/gpl.html
 *
 */

#include <stdio.h>
#include <wiringPi.h>
#include <signal.h>

/* LED Pin - wiringPi pin 0 is BCM_GPIO 17. */

#define	LED	0

void blinkExit(int dummy) {
  /*
    clean everything and exit 
  */
  printf("blink: Cleaning up\n");
  digitalWrite(LED, LOW);
  exit(0);
}

int main (void)
{
  
  printf ("Raspberry Pi blink\n") ;
  /*
    capture ^C to gracefully exit the program
  */
  signal(SIGINT,blinkExit);
  
  wiringPiSetup () ;            /* this will initialize the wiringPi system          */
  
  pinMode (LED, OUTPUT) ;       /* pinMode allows to set the pin to input or output  */

  for (;;)
  {
    digitalWrite (LED, HIGH) ;	/* This switches the LED on                          */
    delay (500) ;		/* waiting for 1/2 second                            */
    digitalWrite (LED, LOW) ;	/* Switching the LED off again                       */
    delay (500) ;
  }
  return 0 ;
}
